Learn R Programming

MIPHENO (version 1.2)

mad.scores: Calculates the mad score (zscore)

Description

Returns a dataframe with the desired score (e.g. Zscore) for observation based on the algorithm for calculating Z scores described in Lu et al 2008. Calculations are done based on value of parameter.

Usage

mad.scores(data, parameter='FLATCODE', n=3, out=c('Zscore', 'label'), ...)

Arguments

data
Dataframe or Matrix of inputs for which the zscore is to be calculated
parameter
The parameter (given by column name) on which the mad score is to be calculated. This is the only non-numeric column allowed.
n
the number of Median Absolute Deviations (MAD) from the center which is considered a 'mutant' or putative hit.
out
The desired output value, either the 'Zscore' (quantitative) or 'label' (qualitative, 3 classes).
...
Other parameters.

Value

mad.scores returns a dataframe containing the Zscores or labels for the observations. The first column will contain the parameter label. If data will be returned in the same order as it was input so long as a sort based on parameter was completed ahead of time.

Details

Data should be presorted according to any identifiers and parameter as labels not used in the calculations will be removed. data should be a dataframe with parameter as a factor (or character) and the rest of the values numeric.

Each column (other than parameter) is considered independent. Rows (individual responses) are extracted from data according to parameter and the MAD is calculated for each column (assay). If out = 'label', then a test is done to see if the result (Zscore) is greater or less than abs(n) and scored 'high' or 'low' accordingly.

References

Bell SM, Burgoon LD, Last RL. MIPHENO: Data normalization for high throughput metabolite analysis. BMC Bioinformatics 2012, 13(10) Lu Y, et al. New connections across pathways and cellular processes: Industrialized mutant screening reveals novel associations between diverse phenotypes in Arabidopsis. Plant Physiol 2010, 152(2):529-540

Examples

Run this code
 #See the sweave document in the corresponding paper for examples

Run the code above in your browser using DataLab