parameter column) is treated as a separate assay.
Therefore if one 'group' does not meet the criteria for inclusion in 1
assay (column value), but does for all others, only the data for the assay
failing the quality control will be removed.
rm.outliers(data, parameter='FLATCODE', n=3, ...)rm.outliers returns a dataframe containing data with values not
passing the filter converted to NA.
parameter
prior to running command. Order will be retained if this is followed.
data should be a dataframe with a parameter serving as a label
and the rest of the values numeric. Note that parameter should be the
attribute where the most error is expected. A visual inspection using box
and whisker plots may be helpful in determining the best variable to use.
data is first broken down into groups based on parameter. Both
the group median and the median of all groups (global median) is calculated.
Groups where the absolute value of the difference between the group median
and global median is greater than n * MAD(group medians) for a
given attribute (column) have their values removed (ie set to NA). Data for
the group is retained for columns that pass this criteria.
#See the sweave document in the corresponding paper for examples
Run the code above in your browser using DataLab