parameter.
mad.scores(data, parameter='FLATCODE', n=3, out=c('Zscore', 'label'), ...)mad.scores returns a dataframe containing the Zscores or labels for
the observations. The first column will contain the parameter label.
If data will be returned in the same order as it was input so long as a sort
based on parameter was completed ahead of time.
parameter
as labels not used in the calculations will be removed. data should
be a dataframe with parameter as a factor (or character) and the
rest of the values numeric. Each column (other than parameter) is considered independent. Rows
(individual responses) are extracted from data according to
parameter and the MAD is calculated for each column (assay).
If out = 'label', then a test is done to see if the result (Zscore) is
greater or less than abs(n) and scored 'high' or 'low' accordingly.
#See the sweave document in the corresponding paper for examples
Run the code above in your browser using DataLab